@@ -66,13 +66,13 @@ class IosVerify(object):
         if self.application_path is None:
             log.error("Path to application is required. application_path must"
                       " be set in command line options")
-            return False
+            return support.EXIT_FAILURE
 
         success = iossupport.execute_codesign_system_call(
             self.application_path)
         if not success:
             log.error("Error in codesign system call")
-            return False
+            return support.EXIT_FAILURE
 
         # Parse entitlement plist output
         entitlements_plist_path = \
@@ -82,7 +82,7 @@ class IosVerify(object):
             entitlements_plist_path)
         if entitlement_plist is None:
             log.error("Entitlement plist could not be read")
-            return False
+            return support.EXIT_FAILURE
 
         # Read the AirshipConfig from the app
         if self.plist is None:
@@ -100,7 +100,7 @@ class IosVerify(object):
 
         # Check local entitlement settings and app configuration
         if not self.verification_info.check_aps_environment():
-            return False
+            return support.EXIT_FAILURE
 
         # If there is no plist, there is no reason to verify anything
         # else. This is done after extracting the entitlements, but
@@ -110,33 +110,33 @@ class IosVerify(object):
             if self.diagnostic:
                 self.verification_info.log_diagnostic_information()
             log.error(NO_CONFIG_PLIST_ERROR)
-            return False
+            return support.EXIT_FAILURE
 
         # Make API verification request
         request = iossupport.get_verification_request(self.verification_info)
         response = iossupport.make_request_against_api(request)
         if response.error is not None:
             log.error("API verification request failed")
-            return False
+            return support.EXIT_FAILURE
         iossupport.log.debug("Response %s", response)
 
         # API response dependent tests
         apns_server = self.verification_info.check_apns_server(response.json)
         if not apns_server:
             log.error("APNS server is not configured properly")
-            return False
+            return support.EXIT_FAILURE
 
         bundle_id = self.verification_info.check_bundle_id(response.json)
         if not bundle_id:
             log.error("Bundle id mismatch")
-            return False
+            return support.EXIT_FAILURE
 
         if self.diagnostic:
             # Print diagnostic info, this has the side effect of printing
             # to a file
             self.verification_info.log_diagnostic_information()
 
-        return True
+        return support.EXIT_SUCCESS
 
 
 class AndroidVerify(object):
@@ -289,7 +289,8 @@ def ios_main():
     success = verify.execute_xcode_verify()
     # There is the possibility of a file logger
     logging.shutdown()
-    if success:
+
+    if success == support.EXIT_SUCCESS:
         log.debug("Successful verification")
         return support.EXIT_SUCCESS
     else:
